<?php

$bus = getListaBUFromBitrix(); // Obtém o array de BUs

// Se não houver BUs, usa um valor padrão para evitar falhas
if (!$bus) {
    // Caso a consulta não retorne BUs, usaremos um valor padrão
    $bus = [
        "API FORA"
    ];
}
?>

<style>
  .offcanvas-custom {
    width: 40% !important;
    min-width: 320px;
  }
  #editorEmpresa {
    width: 50%;  /* Ajuste do tamanho para 50% */
  }
</style>

<div class="offcanvas offcanvas-end offcanvas-custom" tabindex="-1" id="painelSenha" aria-labelledby="painelSenhaLabel">
  <div class="offcanvas-header">
    <h5 class="offcanvas-title" id="painelSenhaLabel">Detalhes da Senha</h5>
    <button type="button" class="btn-close text-reset" data-bs-dismiss="offcanvas" aria-label="Fechar"></button>
  </div>
  <div class="offcanvas-body">

    <input type="hidden" id="senha_id" value="">

    <!-- Empresa (BU) -->
    <div class="mb-3">
      <label for="editorEmpresa" class="form-label">Empresa (BU)</label>
      <select id="editorEmpresa" class="form-select">
        <option value="">Selecione...</option>
        <?php foreach ($bus as $bu): ?>
          <option value="<?= htmlspecialchars($bu) ?>"><?= htmlspecialchars($bu) ?></option>
        <?php endforeach; ?>
      </select>
    </div>

    <h5 class="fw-bold mb-4" style="font-size: 25px;" id="editorSistema">CRM de Vendas</h5>

    <div class="mb-3">
      <label for="usuario" class="form-label">Usuário</label>
      <input type="text" class="form-control" id="usuario" readonly>
    </div>

    <div class="mb-3">
      <label for="senha" class="form-label">Senha</label>
      <div class="input-group">
        <input type="password" class="form-control" id="senha" readonly>
        <button id="btnAcaoSenha" class="btn btn-outline-secondary" type="button" title="Ação sobre senha">
          <i id="iconeSenha" class="fa-solid fa-key"></i>
        </button>
      </div>
    </div>

    <div class="mb-4">
      <label for="email" class="form-label">E-mail de Redefinição</label>
      <input type="email" class="form-control" id="email" readonly>
    </div>

    <div class="d-flex gap-2">
      <button id="btnSalvar" class="btn btn-primary" style="display: none;">Salvar</button>
      <button id="btnApagar" class="btn btn-danger">Apagar</button>
      <button id="btnEditar" class="btn btn-warning" style="display: none;">Editar</button>
    </div>

  </div>
</div>

<script>
  function abrirPainelSenha(modo = 'visualizar', dados = null) {
    const painel = new bootstrap.Offcanvas('#painelSenha');
    painel.show();

    document.getElementById('editorEmpresa').value = dados?.empresa || '';
    document.getElementById('editorSistema').textContent = dados?.sistema || 'CRM de Vendas';
    document.getElementById('usuario').value = dados?.usuario || '';
    document.getElementById('senha').value = dados?.senha || '';
    document.getElementById('email').value = dados?.email || '';
    document.getElementById('senha_id').value = dados?.id || '';

    const campos = ['usuario', 'senha', 'email'];
    const btnSalvar = document.getElementById('btnSalvar');
    const somenteLeitura = (modo === 'visualizar');

    campos.forEach(id => {
      document.getElementById(id).readOnly = somenteLeitura;
    });

    // Empresa (select)
    const empresaSelect = document.getElementById('editorEmpresa');
    empresaSelect.disabled = somenteLeitura;

    if (somenteLeitura) {
      btnSalvar.style.display = 'none';
      document.getElementById('btnApagar').style.display = 'none';
      document.getElementById('btnEditar').style.display = 'inline-block';

      const icone = document.getElementById('iconeSenha');
      icone.classList.remove('fa-key');
      icone.classList.add('fa-copy');

      const btnAcao = document.getElementById('btnAcaoSenha');
      btnAcao.title = "Copiar senha";
      btnAcao.onclick = function () {
        const campo = document.getElementById('senha');
        campo.select();
        document.execCommand('copy');
        mostrarCopiado();
      };
    } else {
      btnSalvar.style.display = 'inline-block';
      document.getElementById('btnApagar').style.display = 'inline-block';
      document.getElementById('btnEditar').style.display = 'none';

      const icone = document.getElementById('iconeSenha');
      icone.classList.remove('fa-copy');
      icone.classList.add('fa-key');

      const btnAcao = document.getElementById('btnAcaoSenha');
      btnAcao.title = "Gerar nova senha";
      btnAcao.onclick = function () {
        mostrarGeradorEditor();
      };
    }
  }

  document.addEventListener('DOMContentLoaded', () => {
    const btnSalvar = document.getElementById('btnSalvar');
    if (btnSalvar) {
      btnSalvar.addEventListener('click', salvarSenhaDoPainel);
    }

    const btnApagar = document.getElementById('btnApagar');
    if (btnApagar) {
      btnApagar.addEventListener('click', function () {
        if (typeof mostrarModalExcluir === "function") {
          mostrarModalExcluir();
        }
      });
    }

    const btnEditar = document.getElementById('btnEditar');
    if (btnEditar) {
      btnEditar.addEventListener('click', function () {
        const painel = bootstrap.Offcanvas.getInstance(document.getElementById('painelSenha'));
        if (painel) painel.hide();

        setTimeout(() => {
          abrirPainelSenha('editar', {
            id: document.getElementById('senha_id').value,
            empresa: document.getElementById('editorEmpresa').value,
            sistema: document.getElementById('editorSistema').textContent,
            usuario: document.getElementById('usuario').value,
            senha: document.getElementById('senha').value,
            email: document.getElementById('email').value
          });
        }, 350);
      });
    }
  });
</script>
