let dadosSenhasOriginais = []; // Armazena o conjunto original de senhas

function carregarSenhas() {
  fetch('services/listar_senhas.php?_=' + new Date().getTime())
    .then(response => response.json())
    .then(json => {
      console.log("🔍 Dados retornados do backend:", json); // DEBUG

      if (json.status === 'ok') {
        dadosSenhasOriginais = json.data;
        renderizarTabela(dadosSenhasOriginais);
      } else {
        alert('Erro ao carregar senhas: ' + json.mensagem);
      }
    })
    .catch(error => {
      console.error('❌ Erro ao buscar senhas:', error);
    });
}

function renderizarTabela(senhas) {
  const tbody = document.getElementById('corpoTabelaSenhas');
  tbody.innerHTML = '';

  senhas.forEach(senha => {
    const tr = document.createElement('tr');

    tr.innerHTML = `
      <td>${senha.empresa}</td>
      <td>${senha.sistema}</td>
      <td>${senha.usuario}</td>
      <td>
        ••••••••
        <button class="icon-btn" title="Copiar senha" onclick="copiarSenha('${senha.senha}')">
          <i class="fa-regular fa-copy"></i>
        </button>
      </td>
      <td>${senha.email_recuperacao || ''}</td>
    `;

    const tdAcoes = document.createElement('td');
    tdAcoes.className = 'text-center action-icons';

    senha.email = senha.email_recuperacao || '';

    const btnVer = document.createElement('button');
    btnVer.className = 'icon-btn';
    btnVer.title = 'Ver';
    btnVer.innerHTML = '<i class="fa-regular fa-eye"></i>';
    btnVer.addEventListener('click', () => abrirPainelSenha('visualizar', senha));
    tdAcoes.appendChild(btnVer);

    const btnEditar = document.createElement('button');
    btnEditar.className = 'icon-btn';
    btnEditar.title = 'Editar';
    btnEditar.innerHTML = '<i class="fa-regular fa-pen-to-square"></i>';
    btnEditar.addEventListener('click', () => abrirPainelSenha('editar', senha));
    tdAcoes.appendChild(btnEditar);

    const btnExcluir = document.createElement('button');
    btnExcluir.className = 'icon-btn';
    btnExcluir.title = 'Excluir';
    btnExcluir.innerHTML = '<i class="fa-regular fa-trash-can"></i>';
    btnExcluir.addEventListener('click', () => confirmarExclusao(senha.id));
    tdAcoes.appendChild(btnExcluir);

    tr.appendChild(tdAcoes);
    tbody.appendChild(tr);
  });
}

// Classificação por 'empresa' ou 'sistema'
function classificarPor(campo) {
  const ordenado = [...dadosSenhasOriginais].sort((a, b) =>
    (a[campo] || '').localeCompare(b[campo] || '', 'pt-BR', { sensitivity: 'base' })
  );
  renderizarTabela(ordenado);
}

// Filtro por texto (empresa ou sistema)
function aplicarFiltroPesquisa(valor) {
  const termo = valor.toLowerCase();
  const filtrado = dadosSenhasOriginais.filter(item =>
    (item.empresa || '').toLowerCase().includes(termo) ||
    (item.sistema || '').toLowerCase().includes(termo)
  );
  renderizarTabela(filtrado);
}

// Copiar senha
function copiarSenha(valor) {
  const tempInput = document.createElement('input');
  tempInput.value = valor;
  document.body.appendChild(tempInput);
  tempInput.select();
  document.execCommand('copy');
  document.body.removeChild(tempInput);
  mostrarCopiado();
}

// Confirma exclusão e chama API
function confirmarExclusao(id) {
  const btn = document.getElementById('btnConfirmarExclusao');
  if (btn) {
    btn.onclick = function () {
      fetch('services/excluir_senha.php', {
        method: 'POST',
        headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
        body: 'id=' + encodeURIComponent(id)
      })
        .then(r => r.json())
        .then(json => {
          if (json.status === 'ok') {
            carregarSenhas();

            const modal = bootstrap.Modal.getInstance(document.getElementById('modalExcluir'));
            if (modal) modal.hide();

            const painel = bootstrap.Offcanvas.getInstance(document.getElementById('painelSenha'));
            if (painel) painel.hide();
          } else {
            alert('Erro ao excluir: ' + json.mensagem);
          }
        })
        .catch(error => {
          console.error('❌ Erro ao excluir:', error);
          alert('Erro inesperado ao excluir.');
        });
    };
  }

  mostrarModalExcluir();
}

// Garante que as funções fiquem disponíveis no escopo global para o HTML
window.classificarPor = classificarPor;
window.aplicarFiltroPesquisa = aplicarFiltroPesquisa;

