// Exibe o modal de confirmação de exclusão
function mostrarModalExcluir() {
  const modal = new bootstrap.Modal(document.getElementById('modalExcluir'));
  modal.show();
}

// Exibe o modal de senha copiada por 2 segundos
function mostrarCopiado() {
  const modal = new bootstrap.Modal(document.getElementById('modalCopiado'));
  modal.show();
  setTimeout(() => modal.hide(), 2000);
}

// =======================
// MODAL GERADOR GLOBAL
// =======================

// Abre o modal padrão de geração de senha
function mostrarGerador() {
  gerarSenha(); // Gera uma senha ao abrir
  const modal = new bootstrap.Modal(document.getElementById('modalGerador'));
  modal.show();
}

// Gera a senha conforme o tipo e tamanho selecionado no modal global
function gerarSenha() {
  const tipo = document.getElementById('tipoSenha').value;
  const tamanho = document.getElementById('tamanhoSenha').value;
  document.getElementById('tamanhoLabel').innerText = tamanho;

  let caracteres = '';
  if (tipo === 'numeros') caracteres = '0123456789';
  else if (tipo === 'letras') caracteres = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
  else if (tipo === 'letras_numeros') caracteres = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789';
  else caracteres = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789!@#$%^&*()_+{}[]<>.?/';

  let senha = '';
  for (let i = 0; i < tamanho; i++) {
    senha += caracteres.charAt(Math.floor(Math.random() * caracteres.length));
  }

  document.getElementById('campoSenhaGerada').value = senha;
}

// Copia a senha gerada no modal global
function copiarSenhaGerada() {
  const senha = document.getElementById('campoSenhaGeradaGlobal');
  senha.select();
  document.execCommand('copy');
  mostrarCopiado();
}

// =======================
// MODAL GERADOR DO EDITOR
// =======================

// Gera dinamicamente e exibe o modal de gerador exclusivo para uso dentro do editor.php
function mostrarGeradorEditor() {
  const existente = document.getElementById('modalGeradorEditor');
  if (existente) existente.remove();

  const modalHTML = `
    <div class="modal fade" id="modalGeradorEditor" tabindex="-1" aria-hidden="true">
      <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content p-4">
          <h5 class="modal-title mb-3"><i class="fa-solid fa-gears me-2"></i>Gerador de Senha</h5>
          <div class="mb-3">
            <label class="form-label">Senha Gerada</label>
            <input type="text" id="campoSenhaGeradaEditor" class="form-control" readonly>
          </div>
          <div class="mb-3">
            <label class="form-label">Tamanho: <span id="tamanhoLabelEditor">12</span> caracteres</label>
            <input type="range" class="form-range" min="8" max="100" value="12" id="tamanhoSenhaEditor">
          </div>
          <div class="mb-3">
            <label class="form-label">Tipo de senha</label>
            <select id="tipoSenhaEditor" class="form-select">
              <option value="numeros">Somente números</option>
              <option value="letras">Somente letras</option>
              <option value="letras_numeros">Letras + Números</option>
              <option value="completa" selected>Letras + Números + Símbolos</option>
            </select>
          </div>
          <div class="d-flex gap-2">
            <button class="btn btn-primary" onclick="copiarSenhaGeradaEditor()"><i class="fa-regular fa-copy me-1"></i>Copiar</button>
            <button class="btn btn-secondary" onclick="gerarSenhaEditor()"><i class="fa-solid fa-rotate me-1"></i>Gerar novamente</button>
          </div>
        </div>
      </div>
    </div>
  `;

  document.body.insertAdjacentHTML('beforeend', modalHTML);
  gerarSenhaEditor();

  const modal = new bootstrap.Modal(document.getElementById('modalGeradorEditor'));
  modal.show();

  document.getElementById('modalGeradorEditor').addEventListener('hidden.bs.modal', function () {
    this.remove();
  });
}

// Gera a senha conforme o tipo/tamanho no modal do editor
function gerarSenhaEditor() {
  const tipo = document.getElementById('tipoSenhaEditor').value;
  const tamanho = document.getElementById('tamanhoSenhaEditor').value;
  document.getElementById('tamanhoLabelEditor').innerText = tamanho;

  let caracteres = '';
  if (tipo === 'numeros') caracteres = '0123456789';
  else if (tipo === 'letras') caracteres = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
  else if (tipo === 'letras_numeros') caracteres = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789';
  else caracteres = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789!@#$%^&*()_+{}[]<>.?/';

  let senha = '';
  for (let i = 0; i < tamanho; i++) {
    senha += caracteres.charAt(Math.floor(Math.random() * caracteres.length));
  }

  document.getElementById('campoSenhaGeradaEditor').value = senha;
}

// Copia a senha gerada no modal do editor e preenche automaticamente no campo de senha
function copiarSenhaGeradaEditor() {
  const campo = document.getElementById('campoSenhaGeradaEditor');
  campo.select();
  document.execCommand('copy');

  const campoSenha = document.getElementById('senha');
  if (campoSenha) campoSenha.value = campo.value;

  mostrarCopiado();

  const modal = bootstrap.Modal.getInstance(document.getElementById('modalGeradorEditor'));
  if (modal) modal.hide();
}

// =======================
// CORREÇÕES E BACKDROP
// =======================

document.addEventListener('DOMContentLoaded', () => {
  const btnConfirmar = document.getElementById('btnConfirmarExclusao');
  if (btnConfirmar) {
    btnConfirmar.addEventListener('click', function () {
      const modal = bootstrap.Modal.getInstance(document.getElementById('modalExcluir'));
      if (modal) modal.hide();

      const painel = bootstrap.Offcanvas.getInstance(document.getElementById('painelSenha'));
      if (painel) painel.hide();
    });
  }

  // Remove backdrop caso fique preso
  document.getElementById('painelSenha')?.addEventListener('hidden.bs.offcanvas', () => {
    const backdrop = document.querySelector('.offcanvas-backdrop');
    if (backdrop) backdrop.remove();
  });
});
