<?php
require_once(__DIR__ . '/crestcurrent.php');

// Incluir o arquivo que contém a função de busca de BUs
include __DIR__ . '/services/bitrix_bu.php';

// Tenta obter o usuário atual logado no Bitrix
$user = CRestCurrent::call('user.current');

if (!isset($user['result']['ID'])) {
    header('Location: 404.php');
    exit;
}

session_start();
$_SESSION['usuario_nome'] = trim($user['result']['NAME'] . ' ' . $user['result']['LAST_NAME']);
?>

<!DOCTYPE html>
<html lang="pt-BR">
<head>
  <meta charset="UTF-8">
  <title>Gestor de Senhas</title>
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/css/bootstrap.min.css" rel="stylesheet">
  <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.0/css/all.min.css" rel="stylesheet">
  <link href="assets/css/style.css" rel="stylesheet">
</head>
<body class="bg-light">

  <?php 
    session_start();
    if (!isset($_SESSION['usuario_nome'])) {
        header('Location: 404.php');
        exit;
    }

    $usuario_logado = $_SESSION['usuario_nome'];
  ?>

  <div class="container mt-4">
    <!-- Cabeçalho -->
    <div class="d-flex justify-content-between align-items-center mb-4">
      <h4 class="fw-bold"><i class="fa-solid fa-lock me-2"></i>Gestor de Senhas</h4>
      <span class="text-muted"><?php echo htmlspecialchars($usuario_logado); ?></span>
    </div>

    <!-- Barra de botões -->
    <div class="d-flex flex-wrap align-items-center mb-3 gap-2">
      <button id="btnNovaSenha" class="btn btn-primary">
        <i class="fa-solid fa-plus me-1"></i>Nova Senha
      </button>
      <button class="ghost-btn" onclick="mostrarGerador()">
        <i class="fa-solid fa-key me-1 text-warning"></i>Gerador
      </button>

      <!-- Dropdown de Classificação -->
      <div class="dropdown">
        <button class="ghost-btn dropdown-toggle" data-bs-toggle="dropdown" aria-expanded="false">
          <i class="fa-solid fa-sort me-1 text-info"></i>Classificação
        </button>
        <ul class="dropdown-menu">
          <li><a class="dropdown-item" href="#" onclick="classificarPor('empresa')">Classificar por Empresa</a></li>
          <li><a class="dropdown-item" href="#" onclick="classificarPor('sistema')">Classificar por Sistema</a></li>
        </ul>
      </div>

      <!-- Campo de Pesquisa -->
      <div class="ms-auto">
        <input type="search" class="form-control" placeholder="🔍 Pesquisar..." oninput="aplicarFiltroPesquisa(this.value)">
      </div>
    </div>

    <!-- Tabela -->
    <div class="table-responsive">
      <table class="table table-bordered bg-white" id="tabelaSenhas">
        <thead class="table-light">
          <tr>
            <th>Empresa</th>
            <th>Sistema*</th>
            <th>Usuário*</th>
            <th>Senha*</th>
            <th>E-mail de Redefinição</th>
            <th class="text-center">Ações</th>
          </tr>
        </thead>
        <tbody id="corpoTabelaSenhas">
          <!-- preenchido via JS -->
        </tbody>
      </table>
    </div>
  </div>

  <!-- Campo oculto para controle de ID de senha -->
  <input type="hidden" id="senha_id">

  <!-- Modais e Painel -->
  <?php include 'app/editor.php'; ?>
  <?php include 'app/modal/modal_excluir.php'; ?>
  <?php include 'app/modal/modal_copiado.php'; ?>
  <?php include 'app/modal/modal_gerador.php'; ?>
  <?php include 'app/modal/modal_sucesso.php'; ?>

  <!-- Scripts -->
  <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.2/dist/js/bootstrap.bundle.min.js"></script>
  <script src="assets/js/modais.js"></script>
  <script src="assets/js/salvarSenha.js"></script>
  <script src="assets/js/listarSenhas.js"></script>
  <script src="assets/js/excluirSenha.js"></script>
  <script src="assets/js/principal.js"></script>
  <script src="assets/js/fixBackdrop.js"></script>

  <script>
    document.addEventListener('DOMContentLoaded', () => {
      carregarSenhas();

      document.getElementById('btnNovaSenha').addEventListener('click', function () {
        abrirPainelSenha('editar', {
          id: '',
          empresa: '',
          sistema: '',
          usuario: '',
          senha: '',
          email: '',
          categoria_id: ''
        });
      });
    });
  </script>

</body>
</html>
