<?php
require_once __DIR__ . '/db.php';                 // db.php está na mesma pasta
require_once __DIR__ . '/../seguranca.php';       // segurança.php está na raiz

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
  $id = $_POST['id'] ?? null;
  $empresa = trim($_POST['empresa'] ?? '');  // Obtém o valor do campo "empresa" (BU)
  $sistema = trim($_POST['sistema'] ?? '');  // Obtém o valor do campo "sistema" (campo de texto)
  $usuario = trim($_POST['usuario'] ?? '');
  $senha = trim($_POST['senha'] ?? '');
  $email = trim($_POST['email'] ?? '');
  $categoria = $_POST['categoria_id'] ?? null;
  $bitrix_user_id = $_POST['bitrix_user_id'] ?? null;

  // Verifica se os campos obrigatórios foram preenchidos
  if (!$empresa || !$sistema || !$usuario || !$senha) {
    echo json_encode(['status' => 'erro', 'mensagem' => 'Campos obrigatórios ausentes']);
    exit;
  }

  try {
    // Criptografando a senha
    $chave = carregarChaveSecreta();
    $senhaCriptografada = criptografarSenha($senha, $chave);

    if ($id) {
      // Atualização do registro
      $stmt = $pdo->prepare("
        UPDATE senhas 
        SET empresa = ?, sistema = ?, usuario = ?, senha = ?, email_recuperacao = ?, categoria_id = ?, bitrix_user_id = ?, atualizado_em = NOW()
        WHERE id = ?
      ");
      $stmt->execute([$empresa, $sistema, $usuario, $senhaCriptografada, $email, $categoria, $bitrix_user_id, $id]);

      $resposta = ['status' => 'ok', 'mensagem' => 'Senha atualizada com sucesso.', 'id' => $id];
    } else {
      // Inserção de novo registro
      $stmt = $pdo->prepare("
        INSERT INTO senhas (empresa, sistema, usuario, senha, email_recuperacao, categoria_id, bitrix_user_id) 
        VALUES (?, ?, ?, ?, ?, ?, ?)
      ");
      $stmt->execute([$empresa, $sistema, $usuario, $senhaCriptografada, $email, $categoria, $bitrix_user_id]);

      $novoId = $pdo->lastInsertId();
      $resposta = ['status' => 'ok', 'mensagem' => 'Senha criada com sucesso.', 'id' => $novoId];
    }

    // Garante envio imediato da resposta (sem buffering)
    ob_clean();
    echo json_encode($resposta);
    flush();

  } catch (PDOException $e) {
    echo json_encode(['status' => 'erro', 'mensagem' => $e->getMessage()]);
  }
} else {
  echo json_encode(['status' => 'erro', 'mensagem' => 'Requisição inválida']);
}
